/***************************************************************************
 *   copyright       : (C) 2012-2014 by Pascal Brachet                     *
 *   http://www.xm1math.net/pdfadd/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 * Parts of this file come from the documentation of Qt. It was originally *
 * published as part of Qt Quarterly.                                      *
 *                                                                         *
 ***************************************************************************/

#ifndef PDFDOCUMENTWIDGET_H
#define PDFDOCUMENTWIDGET_H

#include <QLabel>
#include <QRectF>
#include <QPainterPath>
#include <QTimer>

#if defined(POPPLER20)
#include "texmaker_popplerqt20/poppler-qt4.h"
#elif defined(POPPLER22)
#include "texmaker_popplerqt22/poppler-qt4.h"
#elif defined(POPPLER24EMB)
#include "texmaker_popplerqt5_24/poppler-qt5.h"
#elif defined(POPPLER24)
#include <poppler-qt5.h>
#else
#include <poppler-qt4.h>
#endif

class PdfDocumentWidget : public QLabel
{
    Q_OBJECT

public:
    PdfDocumentWidget(QWidget *parent = 0, int page=0,Poppler::Page *dp=0 );
    ~PdfDocumentWidget();
    Poppler::Page *doc_page;
    QMatrix matrix() const;
    qreal scale() const;
    int numPage;
public slots:
    void updatePixmap();
    void createblankPixmap(int w, int h);
    void setScale(qreal scale);
    void changeScale(qreal scale);
    void setHighlightPath(const QPainterPath& path);
    void setSearchPath(const QPainterPath& path);
    void clearHighlight();
    void clearPaths();


protected:
    void mousePressEvent(QMouseEvent *event);
    void mouseMoveEvent(QMouseEvent *event);
    void mouseReleaseEvent(QMouseEvent *event);
signals:
    void gotoDest(int,int,int);
    void updateDone(int);
    void pressOnPoint(QPoint p);
    void moveOnPoint(QPoint p);
private:
    Poppler::Link *currentLink;
    int currentPage;
    qreal scaleFactor;
    QPainterPath highlightPath, searchPath;
    QTimer highlightRemover;
    bool handmode;
};

#endif
